Date: 2014-05-14 18:49:00

## NanoCap

Copyright (c) 2013 M. Robinson

### 1 Introduction

NanoCap provides both libraries and a standalone application for the construction of capped nanotubes of arbitrarily chirality and fullerenes of any radius. Structures are generated by constructing a set of optimal dual graph topologies which are subsequently optimised using a carbon interatomic potential. Combining this approach with a GUI featuring 3D rendering capabilities allows for the rapid inspection of physically sensible structures which can be used as input for molecular simulation.

The NanoCap source and builds for different platforms can be found at:

http://sourceforge.net/projects/nanocap/